@@ -1,7 +1,7 @@
-Discrete_Discrepancy<-function(Design,a,b){
+Discrete_Discrepancy<-function(Design,a=1,b=0.5){
   matrix<-as.matrix(Design)
   s<-ncol(matrix)
-  q<-length(unique(matrix))
+  q<-length(unique(c(matrix)))
   n<-nrow(matrix)
   collect_for_sum<-c()
   for(i in 1:(nrow(matrix)-1)){
@@ -10,6 +10,9 @@ Discrete_Discrepancy<-function(Design,a,b){
       now<-length(substract_row[substract_row!=0])
       hamming<-length(matrix[i,])-now
       collect_for_sum<-c(collect_for_sum,(a/b)^hamming)
+      # if(hamming>1){
+      #   return(message("Meeting number (Hamming Distance) should not be >1 "))
+      # }
     }
   }
   DD<--((a+((q-1)*b))/q)^s+((a^s)/n)+((2*(b^s))/(n^2))*sum(collect_for_sum)
@@ -20,3 +23,4 @@ Discrete_Discrepancy<-function(Design,a,b){
   list1=list("Discrete Discrepancy Measure"=DD,"Lower Bound of Discrete Discrepancy Measure"=LDD)
 return(list1)
   }
+
